==> trollius-fixers-0.1.1.tar.gz: trollius-fixers-0.1.1/setup.py <==
# #!/usr/bin/env python

# MIT License
#
# Copyright (c) 2017 Bruce Merry
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from setuptools import setup, find_packages

setup(
    name='trollius-fixers',
    version='0.1.1',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'trollius2asyncio = trollius_fixers.trollius2asyncio:main'
        ]
    },
    author='Bruce Merry',
    description='Convert trollius code to asyncio',
    long_description='''
        A tool based on lib2to3 for converting code using trollius to use
        asyncio. After installation, run *trollius2asyncio*. It works in the
        same way as 2to3.
        ''',
    license='MIT',
    keywords='2to3 asyncio trollius',
    url='https://github.com/bmerry/trollius_fixers',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: System :: Networking'
    ]
)

==> trollius-fixers-0.2.tar.gz: trollius-fixers-0.2/setup.py <==
#!/usr/bin/env python

# MIT License
#
# Copyright (c) 2017 Bruce Merry
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from setuptools import setup, find_packages


with open('README.md') as f:
    readme = f.read()


setup(
    name='trollius-fixers',
    version='0.2',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'trollius2asyncio = trollius_fixers.trollius2asyncio:main'
        ]
    },
    author='Bruce Merry',
    description='Convert trollius code to asyncio',
    long_description=readme,
    long_description_content_type='text/markdown',
    license='MIT',
    keywords='2to3 asyncio trollius',
    url='https://github.com/bmerry/trollius-fixers',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: System :: Networking'
    ]
)
